@@ -1,12 +1,11 @@
+import inspect
 import typing as tp
 import warnings
 
+from satella.coding.typing import T, U
 from satella.exceptions import PreconditionError
 
-T = tp.TypeVar('T')
-U = tp.TypeVar('U')
 Expression = tp.NewType('Expression', str)
-ExcType = tp.Type[Exception]
 
 
 # noinspection PyPep8Naming
@@ -90,6 +89,7 @@ def memoize(fun):
                 v = fun(*args, **kwargs)
                 fun.memoizer[args] = v
                 return v
+
     return inner
 
 
@@ -106,13 +106,30 @@ def wraps(cls_to_wrap: tp.Type) -> tp.Callable[[tp.Type], tp.Type]:
 
     def outer(cls: tp.Type) -> tp.Type:
         if hasattr(cls_to_wrap, '__doc__'):
-            cls.__doc__ = cls_to_wrap.__doc__
+            try:
+                cls.__doc__ = cls_to_wrap.__doc__
+            except AttributeError:
+                pass
         if hasattr(cls_to_wrap, '__name__'):
-            cls.__name__ = cls_to_wrap.__name__
+            try:
+                cls.__name__ = cls_to_wrap.__name__
+            except (AttributeError, TypeError):
+                pass
         if hasattr(cls_to_wrap, '__module__'):
-            cls.__module__ = cls_to_wrap.__module__
+            try:
+                cls.__module__ = cls_to_wrap.__module__
+            except AttributeError:
+                pass
         if hasattr(cls_to_wrap, '__annotations__'):
-            cls.__annotations__ = cls_to_wrap.__annotations__
+            try:
+                cls.__annotations__ = cls_to_wrap.__annotations__
+            except (AttributeError, TypeError):
+                pass
+        try:
+            sig = inspect.signature(cls_to_wrap)
+            cls.__signature__ = sig
+        except (TypeError, ValueError, RecursionError, AttributeError):
+            pass
         return cls
 
     return outer
@@ -145,7 +162,7 @@ def has_keys(keys: tp.List[str]):
 
 
 def short_none(clb: tp.Union[Expression, tp.Callable[[T], U]]) -> tp.Callable[
-        [tp.Optional[T]], tp.Optional[U]]:
+    [tp.Optional[T]], tp.Optional[U]]:
     """
     Accept a callable. Return a callable that executes it only if passed a no-None arg,
     and returns its result. If passed a None, return a None
